#include "ramc_pa_define.ddl"
#include "SIPAST_Macros_300.inc"

#ifndef LOW_FLOW_CUTOFF_DEFAULT_SELECT
#define LOW_FLOW_CUTOFF_DEFAULT_SELECT	trans_volume_flow_upper_limit / 20  // 5%
#endif

#ifndef FLOW_SCALE_MIN_VALUE_SELECT
#define FLOW_SCALE_MIN_VALUE_SELECT	trans_volume_flow_lower_limit 
#endif

#ifndef MAX_LOW_FLOW_CUTOFF
#define MAX_LOW_FLOW_CUTOFF		trans_volume_flow_upper_limit / 5   // 20%
#endif

#define PERCENT_HUNDRED			100.0
#define PERCENT_NULL			0.0

//**********************************************************************
//    Transducer Block 1 (TB0): Flow sensor	(Slot 2)
//**********************************************************************

BLOCK transducer_block
{
	TYPE	TRANSDUCER;
	NUMBER	1;
}

trans_blk_reserve	LIKE VARIABLE	phys_blk_reserve
{ }

VARIABLE trans_blk_object
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	3,	[blk_block_object_TRANSDUCER]		}
	}
	HANDLING	READ;
}

VARIABLE trans_blk_parent_class
{
	LABEL		[blk_parent_class];
	HELP		[trans_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	3,	[trans_blk_parent_class_FLOW]	}
	}
	HANDLING	READ;
}

VARIABLE trans_blk_class
{
	LABEL		[blk_class];
	HELP		[trans_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	1,	[standard]		},
		{	6,	"Variable Area"		},
		{	250,	[not_used] 		},
		{	251,	[none]			},
		{	252,	[unknown]		},
		{	253,	[special]		}
	}
	HANDLING	READ;
}

trans_blk_dd_reference		LIKE VARIABLE	phys_blk_dd_reference
{
}

trans_blk_dd_rev		LIKE VARIABLE	phys_blk_dd_rev
{
}

trans_blk_profile		LIKE VARIABLE	phys_blk_profile
{
}

trans_blk_profile_rev		LIKE VARIABLE	phys_blk_profile_rev
{
}

trans_blk_execution_time	LIKE VARIABLE	phys_blk_execution_time
{
}

trans_blk_num_parameters	LIKE VARIABLE	phys_blk_num_parameters
{
}

trans_blk_index_view_1		LIKE VARIABLE	phys_blk_index_view_1
{
}

trans_blk_num_view_lists	LIKE VARIABLE	phys_blk_num_view_lists
{
}

trans_st_rev			LIKE VARIABLE	phys_st_rev
{
}

trans_tag_desc			LIKE VARIABLE	phys_tag_desc
{
}

trans_strategy			LIKE VARIABLE	phys_strategy
{
}

trans_alert_key			LIKE VARIABLE	phys_alert_key
{
}

trans_target_mode		LIKE VARIABLE	phys_target_mode
{
}

trans_actual_mode		LIKE VARIABLE	phys_actual_mode
{
}

trans_permitted_mode		LIKE VARIABLE	phys_permitted_mode
{
}

trans_normal_mode		LIKE VARIABLE	phys_normal_mode
{
}

trans_current_state_alarm_sum	LIKE VARIABLE	phys_current_state_alarm_sum
{
}

trans_unacknowledged_state_alarm_sum	LIKE VARIABLE	phys_unacknowledged_state_alarm_sum
{
}

trans_unreported_state_alarm_sum    	LIKE VARIABLE	phys_unreported_state_alarm_sum
{
}

trans_disabled_state_alarm_sum		LIKE VARIABLE	phys_disabled_state_alarm_sum
{
}



//---------------------------------------------------------------------
//    Transducer Block 1: Additional parameters for YEC RAMC
//---------------------------------------------------------------------

VARIABLE trans_calibration_factor
{
	/* ST_REV */
	LABEL		[trans_flow_calibration_factor];
	HELP		[trans_flow_calibration_factor_help];
	CLASS		CONTAINED;
	TYPE        	FLOAT
	{   
		DEFAULT_VALUE   	1.0;
		MIN_VALUE		0.999999;
		MAX_VALUE		1.000001;
		EDIT_FORMAT		"8.3f";
		DISPLAY_FORMAT		".3f";
	}
}

VARIABLE trans_low_flow_cutoff
{
	/* STORAGE in Flash_eeprom */
	/* ST_REV */
	LABEL		[trans_flow_low_flow_cutoff];
	HELP		[trans_flow_low_flow_cutoff_help];
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE	0.0; 
	}   
	HANDLING	READ & WRITE;
}

VARIABLE trans_measurement_mode
{
	/* ST_REV */
	LABEL		[trans_flow_device_mode];
	HELP		[trans_flow_device_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0 ;	// Profil: DEFAULT_VALUE	0 ;
		{   0,  [uni_directional]	},
		{   1,  [bi_directional]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans_flow_direction
{
	/* ST_REV */
	LABEL		[trans_flow_flow_direction];
	HELP		[trans_flow_flow_direction_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,  [pos_direction]	},
		{	1,  [neg_direction]	}
	}
	HANDLING	READ & WRITE;
}


UNIT trans_zero_point_unitrelation
{
    trans_zero_point_units:
    trans_zero_point
}


VARIABLE trans_zero_point
{
	/* ST_REV */
	LABEL		[trans_flow_zero_point];
	HELP		[trans_flow_zero_point_help];
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE		0.0;
		DISPLAY_FORMAT		".3f";	   
		EDIT_FORMAT		".6f";	   
		MAX_VALUE		0.000001;
		MIN_VALUE		-0.000001;
	}   
	HANDLING	READ & WRITE;

}

VARIABLE trans_zero_point_adjust
{
	LABEL		[trans_flow_zero_point_adjust];
	HELP		[trans_flow_zero_point_adjust_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,  [cancel]	},
		{	1,  [execute]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans_zero_point_units
{
	/* STORAGE in Flash_eeprom */
	LABEL		[digital_units];	
	HELP		[digital_units_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1062 ;
		{ 1062,	[unit_1062],	[unit_1062_help]	},		/* mm/s        */
	}
	HANDLING	READ & WRITE;
}


UNIT trans_nominal_size_unitrelation
{
    trans_nominal_size_units:
    trans_nominal_size
}

VARIABLE trans_nominal_size
{
	/* ST_REV */
	LABEL		[trans_flow_normal_size];
	HELP		[trans_flow_normal_size_help];
	CLASS		CONTAINED;
	TYPE        	FLOAT
	{
		DEFAULT_VALUE 25.40;
	}
	HANDLING	READ & WRITE;

}


VARIABLE trans_nominal_size_units
{
	/* STORAGE in Flash_eeprom */
	LABEL		[trans_flow_normal_size_unit];
	HELP		[trans_flow_normal_size_unit_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1013;				/* mm */
		{ 1013,	[unit_1013],       [unit_1013_help]},	/* mm */
		{ 1019,	[unit_1019],       [unit_1019_help]},	/* inch */
	}
	HANDLING	READ & WRITE;

}



UNIT trans_volume_flow_unitrelation
{
	trans_volume_flow_unit:
	
	trans_volume_flow_value,
	trans_volume_flow_lower_limit,
	trans_volume_flow_upper_limit,
//	func1_AI_pv_upper_range_value,
//	func1_AI_pv_lower_range_value,
	trans_low_flow_cutoff
}


VARIABLE trans_volume_flow_value
{
	LABEL  	 	[trans_volume_flow_value_label];
	HELP    	[trans_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE    	FLOAT;
	HANDLING	READ;
}

VARIABLE trans_volume_flow_status_quality
{
	/* BITMASK 0xfc */

	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0; 
		STATUS_OUTPUT_NO_RCAS
	}
	HANDLING	READ;
}

trans_volume_flow_status_limit				LIKE VARIABLE	trans_volume_flow_status_quality
{
	/* BITMASK 0x03 */
	REDEFINE LABEL	[status_limit];		
	REDEFINE TYPE	ENUMERATED (1)
	{
		STATUS_OUTPUT_LIMIT
	}
}


VARIABLE trans_volume_flow_unit
{
	/* NO STORAGE in Cal_eeprom */
	LABEL		[trans_volume_flow_unit_label];	
	HELP		[digital_units_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{

	    DEFAULT_VALUE 1349;	// Profil: DEFAULT_VALUE 1349 m/h;
	    IF ((trans_fluid_phase == 1) || (trans_fluid_phase == 0))
	    {
		{ 1511,	[unit_1511],	[unit_1511_help]	},		/* 210	cm/s     */
		{ 1512,	[unit_1512],	[unit_1512_help]	},		/* 211	cm/min   */
		{ 1513,	[unit_1513],	[unit_1513_help]	},		/* 212	cm/h     */
		{ 1514,	[unit_1514],	[unit_1514_help]	},		/* 213	cm/d     */
                { 1577, [unit_1577],	[unit_1577_help]	},              /* 186	ml/s  XXX */ 
		{ 1563,	[unit_1563],	[unit_1563_help]	},		/* 215	ml/min    */
		{ 1578,	[unit_1578],	[unit_1578_help]	},		/* 216	ml/h      */
		{ 1347,	[unit_1347],	[unit_1347_help]	},		/* 28	m/s       */
		{ 1348,	[unit_1348],	[unit_1348_help]	},		/* 131	m/min     */
		{ 1349,	[unit_1349],	[unit_1349_help]	},		/* 19	m/h       */
		{ 1350,	[unit_1350],	[unit_1350_help]	},		/* 29	m/d       */
		{ 1351,	[unit_1351],	[unit_1351_help]	},		/* 24	l/s        */
		{ 1352,	[unit_1352],	[unit_1352_help]	},		/* 17	l/min      */
		{ 1353,	[unit_1353],	[unit_1353_help]	},		/* 138	l/h        */
		{ 1354,	[unit_1354],	[unit_1354_help]	},		/* 214	l/d        */
		{ 1356,	[unit_1356],	[unit_1356_help]	},		/* 26	ft/s      */
		{ 1357,	[unit_1357],	[unit_1357_help]	},		/* 15	ft/min    */
		{ 1358,	[unit_1358],	[unit_1358_help]	},		/* 130	ft/h      */
		{ 1359,	[unit_1359],	[unit_1359_help]	},		/* 27	ft/d      */
		{ 1362,	[unit_1362],	[unit_1362_help]	},		/* 22	usgal/s    */
		{ 1363,	[unit_1363],	[unit_1363_help]	},		/* 16	usgal/min  */
		{ 1364,	[unit_1364],	[unit_1364_help]	},		/* 136	usgal/h    */
		{ 1365,	[unit_1365],	[unit_1365_help]	},		/* 235	usgal/d    */
		{ 1367,	[unit_1367],	[unit_1367_help]	},		/* 137	Impgal/s   */
		{ 1368,	[unit_1368],	[unit_1368_help]	},		/* 18	Impgal/min */
		{ 1369,	[unit_1369],	[unit_1369_help]	},		/* 30	Impgal/h   */
		{ 1370,	[unit_1370],	[unit_1370_help]	},		/* 31	Impgal/d   */
		{ 1371,	[unit_1371],	[unit_1371_help]	},		/* 132	bbl/s      */
		{ 1372,	[unit_1372],	[unit_1372_help]	},		/* 133	bbl/min    */
		{ 1373,	[unit_1373],	[unit_1373_help]	},		/* 134	bbl/h      */
		{ 1374,	[unit_1374],	[unit_1374_help]	},		/* 135	bbl/d      */
		{ 1633,	[unit_1633],	[unit_1633_help]	},		/* 221	hl/s       */
		{ 1634,	[unit_1634],	[unit_1634_help]	},		/* 222	hl/min     */
		{ 1635,	[unit_1635],	[unit_1635_help]	},		/* 223	hl/h       */
		{ 1636,	[unit_1636y],	[unit_1636y_help]	},		/* 224	hl/d       */
	    }
	    ELSE
	    {
	        IF (trans_fluid_phase == 2)
	        {
		  { 1588,	[unit_1588],	[unit_1588_help]	},		/* 246	Nm/s      */
		  { 1589,	[unit_1589],	[unit_1589_help]	},		/* 241	Nm/min    */
		  { 1590,	[unit_1590],	[unit_1590_help]	},		/* 121	Nm/h      */
		  { 1591,	[unit_1591y],	[unit_1591y_help]	},		/* 247	Nm/d      */
		  { 1592,	[unit_1592],	[unit_1592_help]	},		/* 248	Nl/s       */
		  { 1593,	[unit_1593],	[unit_1593_help]	},		/* 242	Nl/min     */
		  { 1594,	[unit_1594],	[unit_1594_help]	},		/* 122	Nl/h       */
		  { 1595,	[unit_1595y],	[unit_1595_help]	},		/* 249	Nl/d       */
	        }
	        ELSE
	        {
	          IF (trans_fluid_phase == 3)
	          {
		    { 1596,	[unit_1596],	[unit_1596_help]	},		/* 200	Sm/s      */
		    { 1597,	[unit_1597y],	[unit_1597y_help]	},		/* 201	Sm/min    */
		    { 1598,	[unit_1598y],	[unit_1598y_help]	},		/* 202	Sm/h      */
		    { 1599,	[unit_1599y],	[unit_1599y_help]	},		/* 203	Sm/d      */
		    { 1600,	[unit_1600],	[unit_1600_help]	},		/* 204	Sl/s       */
		    { 1601,	[unit_1601],	[unit_1601_help]	},		/* 205	Sl/min     */
		    { 1602,	[unit_1602],	[unit_1602_help]	},		/* 206	Sl/h       */
		    { 1603,	[unit_1603],	[unit_1603_help]	},		/* 207	Sl/d       */
		    { 1604,	[unit_1604y],	[unit_1604y_help]	},		/* 208	scf/s      */
		    { 1360,	[unit_1360],	[unit_1360y_help]	},		/* 123	scf/min    */
		    { 1361,	[unit_1361],	[unit_1361y_help]	},		/* 240	scf/h      */
		    { 1605,	[unit_1605y],	[unit_1605y_help]	},		/* 209	scf/d      */
		    { 1524,     [unit_1524y],   [unit_1524y_help]	},		/* 190	sgal/minXXX*/
		    { 1525,     [unit_1525y],   [unit_1525y_help]	} 		/* 191	sgal/h  XXX*/
	          }
	        }
	    }
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans_volume_flow_lower_limit
{
	/* STORAGE in CAL_eeprom */
	/* ST_REV */
	LABEL		[trans_vol_flow_low_limit];	
	HELP		[trans_vol_flow_low_limit_help];
	CLASS		CONTAINED & SERVICE ;
	TYPE        	FLOAT
	{
			DEFAULT_VALUE	0.0 ;	/* m/h */
	}   
	HANDLING	READ;
}

VARIABLE trans_volume_flow_upper_limit
{
	/* STORAGE in CAL_eeprom */
	/* ST_REV */

	LABEL		[trans_vol_flow_high_limit];	
	HELP		[trans_vol_flow_high_limit_help];
	CLASS		CONTAINED & SERVICE ;
	TYPE        	FLOAT
	{
			DEFAULT_VALUE	1.0 ;	/* m/h */
	}   
	HANDLING	READ;
}




UNIT trans_mass_flow_unitrelation
{
	trans_mass_flow_unit:
	
	trans_mass_flow_value,
	trans_mass_flow_lower_limit,
	trans_mass_flow_upper_limit
}


VARIABLE trans_mass_flow_value
{
	LABEL 	  	[trans_mass_flow_value_label];
	HELP    	[trans_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE    	FLOAT;
	HANDLING	READ;
}

VARIABLE trans_mass_flow_status_quality
{
	/* BITMASK 0xfc */

	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0; 
		STATUS_OUTPUT_NO_RCAS
	}
	HANDLING	READ;
}

trans_mass_flow_status_limit				LIKE VARIABLE	trans_mass_flow_status_quality
{
	/* BITMASK 0x03 */
	REDEFINE LABEL	[status_limit];		
	REDEFINE TYPE	ENUMERATED (1)
	{
		STATUS_OUTPUT_LIMIT
	}
}

VARIABLE trans_mass_flow_unit
{
	/* NO STORAGE in Cal_eeprom */
	LABEL		[trans_mass_flow_unit_label];	
	HELP		[digital_units_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1328 ;	// Profil: DEFAULT_VALUE 1328 t/h ;
		{ 1326,	[unit_1326],	[unit_1326_help]	}, /* 217	t/s        */
		{ 1327,	[unit_1327],	[unit_1327_help]	}, /* 77	t/min      */
		{ 1328,	[unit_1328],	[unit_1328_help]	}, /* 78	t/h        */
		{ 1329,	[unit_1329],	[unit_1329_help]	}, /* 79	t/d        */
		{ 1322,	[unit_1322],	[unit_1322_help]	}, /* 73	kg/s       */
		{ 1323,	[unit_1323],	[unit_1323_help]	}, /* 74	kg/min     */
		{ 1324,	[unit_1324],	[unit_1324_help]	}, /* 75	kg/h       */
		{ 1325,	[unit_1325],	[unit_1325_help]	}, /* 76	kg/d       */
		{ 1330,	[unit_1330],	[unit_1330_help]	}, /* 80	lb/s       */
		{ 1331,	[unit_1331],	[unit_1331_help]	}, /* 81	lb/min     */
		{ 1332,	[unit_1332],	[unit_1332_help]	}, /* 82	lb/h       */
		{ 1333,	[unit_1333],	[unit_1333_help]	}, /* 83	lb/d       */
		{ 1318,	[unit_1318],	[unit_1318_help]	}, /* 70	g/s        */
		{ 1319,	[unit_1319],	[unit_1319_help]	}, /* 71	g/min      */
		{ 1320,	[unit_1320],	[unit_1320_help]	}, /* 72	g/h        */
		{ 1321,	[unit_1321],	[unit_1321_help]	}, /* 218	g/d        */
		{ 1334,	[unit_1334],	[unit_1334_help]	}, /* 219	Ston/s     */
		{ 1335,	[unit_1335],	[unit_1335_help]	}, /* 84	Ston/min   */
		{ 1336,	[unit_1336],	[unit_1336_help]	}, /* 85	Ston/h     */
		{ 1337,	[unit_1337],	[unit_1337_help]	}, /* 86	Ston/d     */
		{ 1338,	[unit_1338],	[unit_1338_help]	}, /* 220	Lton/s     */
		{ 1339,	[unit_1339],	[unit_1339_help]	}, /* 243	Lton/min   */
		{ 1340,	[unit_1340],	[unit_1340_help]	}, /* 87	Lton/h     */
		{ 1341,	[unit_1341],	[unit_1341_help]	}, /* 88	Lton/d     */
		{ 1526, [unit_1526y],	[unit_1526y_help]	}, /* 192	mg/s   XXX */
		{ 1527, [unit_1527y],	[unit_1527y_help]	}, /* 193	mg/min XXX */
		{ 1528, [unit_1528y],	[unit_1528y_help]	}, /* 194	mg/h   XXX */
		{ 1607, [unit_1607y],   [unit_1607y_help]	}, /* 187	oz/min XXX */
		{ 1608, [unit_1608y],   [unit_1608y_help]	}  /* 188	oz/h   XXX */
	} 
	HANDLING	READ & WRITE;
}

VARIABLE trans_mass_flow_lower_limit
{
	/* STORAGE in CAL_eeprom */
	/* ST_REV */
	LABEL		[trans_mass_flow_low_limit];	
	HELP		[trans_mass_flow_low_limit_help];
	CLASS		CONTAINED & SERVICE ;
	TYPE        	FLOAT
	{
			DEFAULT_VALUE	0.0 ;	/* t/h */
	}   
	HANDLING	READ;
}

VARIABLE trans_mass_flow_upper_limit
{
	/* STORAGE in CAL_eeprom */
	/* ST_REV */
	LABEL		[trans_mass_flow_high_limit];	
	HELP		[trans_mass_flow_high_limit_help];
	CLASS		CONTAINED & SERVICE ;
	TYPE        	FLOAT
	{
			DEFAULT_VALUE	1.0 ;	/* t/h */
	}   
	HANDLING	READ;
}



UNIT trans_density_unitrelation
{
	trans_density_unit:
	trans_density
}

VARIABLE trans_density
{
	LABEL	 	[trans_flow_density];
	HELP	  	[trans_device_density_help_label];
	CLASS CONTAINED & DYNAMIC;
	TYPE  FLOAT ;
	HANDLING READ ;
}

VARIABLE trans_density_status_quality
{
	/* BITMASK 0xfc */

	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_OUTPUT_NO_RCAS
	}
	HANDLING	READ;
}

VARIABLE trans_density_status_limit
{
	/* BITMASK 0x03 */
	LABEL		[status_limit];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_OUTPUT_LIMIT
	}
	HANDLING	READ;
}

VARIABLE trans_density_unit
{
	LABEL	 	[trans_flow_density_unit];
	HELP	  	[trans_device_density_unit_help_label];
	CLASS CONTAINED;
	TYPE  ENUMERATED(2)
	{
		DEFAULT_VALUE 1100;	/* g/cm */ /* mass density */

		{ 1097,	[unit_1097],	[unit_1097_help]	}, /* 92	kg/m     */
		{ 1098,	[unit_1098],	[unit_1098_help]	}, /* 224	Mg/m     */
		{ 1099,	[unit_1099],	[unit_1099_help]	}, /* 225	kg/dm    */
		{ 1100,	[unit_1100],	[unit_1100_help]	}, /* 91	g/cm     */
		{ 1101,	[unit_1101],	[unit_1101_help]	}, /* 226	g/m      */
		{ 1102,	[unit_1102],	[unit_1102_help]	}, /* 245	t/m      */
		{ 1103,	[unit_1103],	[unit_1103_help]	}, /* 96	kg/L      */
		{ 1104,	[unit_1104],	[unit_1104_help]	}, /* 95	g/mL      */
		{ 1105,	[unit_1105],	[unit_1105_help]	}, /* 97	g/L       */
		{ 1106,	[unit_1106],	[unit_1106_help]	}, /* 98	lb/in    */
		{ 1107,	[unit_1107],	[unit_1107_help]	}, /* 94	lb/in    */
		{ 1108,	[unit_1108],	[unit_1108_help]	}, /* 93	lb/in    */
		{ 1109,	[unit_1109],	[unit_1109_help]	}, /* 99	STon/yd  */
		{ 1566,	[unit_1566],	[unit_1566_help]	}, /* 229	mg/m     */
		{ 1564,	[unit_1564],	[unit_1564_help]	}, /* 227	mg/dm    */
		{ 1558,	[unit_1558],	[unit_1558_help]	}, /* 228	mg/L      */
		{ 1559,	[unit_1559],	[unit_1559_help]	}, /* 146	g/L      */
//		{ 1114,	[unit_1114],	[unit_1114_help]	}, /* 90	SGU       */
	}
	HANDLING READ & WRITE ;
}


UNIT trans_temperature_unitrelation
{
	trans_temperature_unit:
	trans_temperature
}


VARIABLE trans_temperature
{
	LABEL		[trans_device_temperature_label];	
	HELP		[trans_device_temperature_help_label];
	CLASS CONTAINED & DYNAMIC;
	TYPE  FLOAT ;
	HANDLING READ ;
}

VARIABLE trans_temperature_status_quality
{
	/* BITMASK 0xfc */

	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_OUTPUT_NO_RCAS
	}
	HANDLING	READ;
}

VARIABLE trans_temperature_status_limit
{
	/* BITMASK 0x03 */
	LABEL		[status_limit];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_OUTPUT_LIMIT
	}
	HANDLING	READ;
}


VARIABLE trans_temperature_unit   
{
	LABEL		[trans_device_temp_unit_label];	
	HELP		[trans_device_temp_unit_help_label];
	CLASS CONTAINED;
	TYPE  ENUMERATED(2)
	{
		DEFAULT_VALUE 1001;   /* C */ /* temperature */
		{ 1000,	[unit_1000],	[unit_1000_help]	}, /* 35	Kelvin    */
		{ 1001,	[unit_1001],	[unit_1001_help]	}, /* 32	C        */
		{ 1002,	[unit_1002],	[unit_1002_help]	}, /* 33	F        */
	}
	HANDLING READ & WRITE ;
}

                  



// Manufacturer specific parameter ////////////////////////////////////////////



UNIT trans_oper_viscosity_unitrelation
{
	trans_oper_viscosity_unit:
	trans_oper_viscosity
}

VARIABLE trans_oper_viscosity
{
	LABEL 		[trans_device_viscosity_label];
	HELP  		[trans_device_viscosity_help_label];
	CLASS 		CONTAINED;
	TYPE  		FLOAT
	{
		DEFAULT_VALUE 0.0;
	}
	HANDLING 	READ;
}


VARIABLE trans_oper_viscosity_unit 
{
	LABEL 		[trans_device_viscosity_unit_label];
	HELP  		[trans_device_viscosity_unit_help_label];
	CLASS 		CONTAINED;
	TYPE  		ENUMERATED(2)
	{
		DEFAULT_VALUE 1521;   /* mPa*s */ /* viscosity */
		{ 1159,	[unit_1159],	[unit_1159_help]	}, /* 180	Pa*s      */
		{ 1161,	[unit_1161],	[unit_1161_help]	}, /* 181	P         */
		{ 1162,	[unit_1162],	[unit_1162_help]	}, /* 55	cP        */
		{ 1521,	[unit_1521y], 	[unit_1521y_help]	}, /* 244	mPa*s     */
		{ 1522,	[unit_1522y], 	[unit_1522y_help]	}, /* 182	kg/ms     */
		{ 1523,	[unit_1523y], 	[unit_1523y_help]	}, /* 183	Ns/m     */
		{ 1160,	[unit_1160],	[unit_1160_help]	}, /* 184	m/s      */
		{ 1163,	[unit_1163],	[unit_1163_help]	}, /* 185	St        */
		{ 1164,	[unit_1164],	[unit_1164_help]	}, /* 45	cSt       */
	}
	HANDLING 	READ;
}


UNIT trans_oper_pressure_unitrelation
{
	trans_oper_pressure_unit:
	trans_oper_pressure
}

VARIABLE trans_oper_pressure
{
	LABEL 		[trans_device_pressure_label];
	HELP  		[trans_device_pressure_help_label];
	CLASS 		CONTAINED;
	TYPE  		FLOAT
	{
		DEFAULT_VALUE 1.0;
	}
	HANDLING 	READ;
}

VARIABLE trans_oper_pressure_unit
{
	LABEL 		[trans_device_pressure_unit_label];
	HELP  		[trans_device_pressure_unit_help_label];
	CLASS 		CONTAINED;
	TYPE  		ENUMERATED(2)
	{
		DEFAULT_VALUE 1137;  /* bar */ /* pressure */
		{ 1130,	[unit_1130],	[unit_1130_help]	}, /* 11	Pa        */
		{ 1132,	[unit_1132],	[unit_1132_help]	}, /* 237	MPa       */
		{ 1133,	[unit_1133],	[unit_1133_help]	}, /* 12	kPa       */
		{ 1137,	[unit_1137],	[unit_1137_help]	}, /* 07	bar       */
		{ 1138,	[unit_1138],	[unit_1138_help]	}, /* 08	mbar      */
		{ 1139,	[unit_1139],	[unit_1139_help]	}, /* 13	torr      */
		{ 1140,	[unit_1140],	[unit_1140_help]	}, /* 14	atm       */
		{ 1141,	[unit_1141],	[unit_1141_help]	}, /* 06	psi       */
		{ 1144,	[unit_1144],	[unit_1144_help]	}, /* 09	g/cm     */
		{ 1145,	[unit_1145],	[unit_1145_help]	}, /* 10	kg/cm    */
		{ 1529,	[unit_1529y], 	[unit_1529y_help]	}, /* 195	N/cm     */
		{ 1530,	[unit_1530y], 	[unit_1530y_help]	}, /* 196	N/mm     */
		{ 1156,	[unit_1156],	[unit_1156_help]	}, /* 02	inHG      */
		{ 1158,	[unit_1158],	[unit_1158_help]	}, /* 05	mmHG      */
		{ 1147,	[unit_1147],	[unit_1147_help]	}, /* 238	inWS      */
		{ 1150,	[unit_1150],	[unit_1150_help]	}, /* 239	mmWS      */
	}
	HANDLING 	READ;
}




UNIT trans_oper_pressure_ref_unitrelation
{
	trans_press_ref_unit:
	trans_pressure_ref
}

VARIABLE trans_pressure_ref
{
	LABEL 		[trans_device_ref_pressure_label];
	HELP  		[trans_device_ref_pressure_help_label];
	CLASS 		CONTAINED;
	TYPE  		FLOAT
	{
		DEFAULT_VALUE 1.013;
	}
	HANDLING 	READ;
}

VARIABLE trans_press_ref_unit
{
	LABEL 		[trans_device_ref_pressure_unit_label];
	HELP  		[trans_device_ref_pressure_unit_help_label];
	CLASS 		CONTAINED;
	TYPE  		ENUMERATED(2)
	{
		DEFAULT_VALUE 1137;  /* bar */ /* pressure */
		{ 1130,	[unit_1130],	[unit_1130_help]	}, /* 11	Pa        */
		{ 1132,	[unit_1132],	[unit_1132_help]	}, /* 237	MPa       */
		{ 1133,	[unit_1133],	[unit_1133_help]	}, /* 12	kPa       */
		{ 1137,	[unit_1137],	[unit_1137_help]	}, /* 07	bar       */
		{ 1138,	[unit_1138],	[unit_1138_help]	}, /* 08	mbar      */
		{ 1139,	[unit_1139],	[unit_1139_help]	}, /* 13	torr      */
		{ 1140,	[unit_1140],	[unit_1140_help]	}, /* 14	atm       */
		{ 1141,	[unit_1141],	[unit_1141_help]	}, /* 06	psi       */
		{ 1144,	[unit_1144],	[unit_1144_help]	}, /* 09	g/cm     */
		{ 1145,	[unit_1145],	[unit_1145_help]	}, /* 10	kg/cm    */
		{ 1529,	[unit_1529y], 	[unit_1529y_help]	}, /* 195	N/cm     */
		{ 1530,	[unit_1530y], 	[unit_1530y_help]	}, /* 196	N/mm     */
		{ 1156,	[unit_1156],	[unit_1156_help]	}, /* 02	inHG      */
		{ 1158,	[unit_1158],	[unit_1158_help]	}, /* 05	mmHG      */
		{ 1147,	[unit_1147],	[unit_1147_help]	}, /* 238	inWS      */
		{ 1150,	[unit_1150],	[unit_1150_help]	}, /* 239	mmWS      */
	}
	HANDLING 	READ;
}





UNIT trans_oper_temperature_unitrelation
{
	trans_oper_temp_unit:
	trans_oper_temperature
}

VARIABLE trans_oper_temperature
{
	LABEL		[trans_oper_temperature_label];	
	HELP		[trans_oper_temperature_help_label];
	CLASS 		CONTAINED;
	TYPE  		FLOAT
	{
		DEFAULT_VALUE 20.0;
	}
	HANDLING 	READ;
}

VARIABLE trans_oper_temp_unit
{
	LABEL 		[trans_oper_temperature_unit_label];
	HELP  		[trans_oper_temperature_unit_help_label];
	CLASS 		CONTAINED;
	TYPE  		ENUMERATED(2)
	{
		DEFAULT_VALUE 1001;   /* C */ /* temperature */
		{ 1000,	[unit_1000],	[unit_1000_help]	}, /* 35	Kelvin    */
		{ 1001,	[unit_1001],	[unit_1001_help]	}, /* 32	C        */
		{ 1002,	[unit_1002],	[unit_1002_help]	}, /* 33	F        */
	}
	HANDLING 	READ;
}


VARIABLE trans_oper_condition
{
	LABEL		[trans_pressure_condition_label];
	HELP		[trans_pressure_condition_help_label];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,  [absolute] },
		{	1,  [gage] },
		{	2,  [gage] },
		{	3,  "Vacuum" "|de|Vacuum" },
	}
	HANDLING	READ;
}


VARIABLE trans_fluid_phase
{
	LABEL		[trans_fluid_phase_label];
	HELP		[trans_fluid_phase_help_label];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,  "Liquid" "|de|Flssigkeit"	},
		{	1,  "Gas in Operation" "|de|Gas im Betriebszustand"	},
		{	2,  "Gas in Normal Cond" "|de|Gas im Normzustand"	},
		{	3,  "Gas in Standard Cond" "|de|Gas im Standardzustand"	},
	}
	HANDLING	READ;
}


VARIABLE trans_flow_reference
{
	LABEL		[trans_flow_reference_label];
	HELP		[trans_flow_reference_help_label];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,  "Volume Flow" "|de|Volumenflu" },
		{	1,  "Mass Flow"	 "|de|Massenflu" }
	}
	HANDLING	READ;
}

VARIABLE trans_commission_no
{
	LABEL		[trans_commision_no_label];
	HELP		[trans_commision_no_help_label];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ;
}


VARIABLE trans_model_code
{
	LABEL		[trans_model_code_label];
	HELP		[trans_model_code_help_label];
	CLASS		CONTAINED;
	TYPE		ASCII (24)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ;
}

VARIABLE trans_fluid_name
{
	LABEL		[trans_fluid_name_label];
	HELP		[trans_fluid_name_help_label];
	CLASS		CONTAINED;
	TYPE		ASCII (22)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ;
}




UNIT trans_totalizer_unitrelation
{
	trans_totalizer_units:
	trans_totalizer
}


VARIABLE trans_totalizer
{
	LABEL 		[trans_totalizer_value_label];
	HELP  		[trans_totalizer_value_help_label];
	CLASS 		CONTAINED & DYNAMIC;
	TYPE  		FLOAT ;
	HANDLING 	READ ;
}

VARIABLE trans_totalizer_status_quality
{
	/* BITMASK 0xfc */

	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0; 
		STATUS_OUTPUT_NO_RCAS
	}
	HANDLING	READ;
}

trans_totalizer_flow_status_limit				LIKE VARIABLE	trans_totalizer_status_quality
{
	/* BITMASK 0x03 */
	REDEFINE LABEL	[status_limit];		
	REDEFINE TYPE	ENUMERATED (1)
	{
		STATUS_OUTPUT_LIMIT
	}
}



VARIABLE trans_totalizer_units
{
	LABEL 		[trans_totalizer_unit_label];
	HELP  		[trans_totalizer_unit_help_label];
	CLASS 		CONTAINED;
	TYPE  		ENUMERATED(2)
	{
	    DEFAULT_VALUE 1034;   /* m */

	    IF (trans_flow_reference == 1)
	    {
		{ 1088,	[unit_1088],	[unit_1088_help]	}, /* 61	kg   */
		{ 1089,	[unit_1089],	[unit_1089_help]	}, /* 60	g    */
		{ 1090,	[unit_1090],	[unit_1090_help]	}, /* 189	mg   */
		{ 1092,	[unit_1092],	[unit_1092_help]	}, /* 62	t    */
		{ 1093,	[unit_1093],	[unit_1093_help]	}, /* 125	oz   */
		{ 1094,	[unit_1094],	[unit_1094_help]	}, /* 63	lb   */
		{ 1095,	[unit_1095],	[unit_1095_help]	}, /* 64	STon */
		{ 1096,	[unit_1096],	[unit_1096_help]	}, /* 65	LTon */
	    }
	    ELSE
	    {


	    IF ((trans_fluid_phase == 0) || (trans_fluid_phase == 1))
	    {
		{ 1034,	[unit_1034],	[unit_1034_help]	}, /* 43	m   */
		{ 1036, [unit_1036],	[unit_1036_help]	}, /* 231	cm  */
		{ 1038,	[unit_1038],	[unit_1038_help]	}, /* 41	l    */
		{ 1040, [unit_1040],	[unit_1040_help]	}, /* 232	ml   */
		{ 1041, [unit_1041],	[unit_1041_help]	}, /* 236	hl   */
		{ 1042, [unit_1042],	[unit_1042_help]	}, /* 113	in  */
		{ 1043,	[unit_1043],	[unit_1043_help]	}, /* 112	ft  */
		{ 1044, [unit_1044],	[unit_1044_help]	}, /* 111	yd  */
		{ 1048,	[unit_1048],	[unit_1048_help]	}, /* 40	US gal */
		{ 1049,	[unit_1049],	[unit_1049_help]	}, /* 42	Impgal */
		{ 1051, [unit_1051],	[unit_1051_help]	}, /* 46	bbl  */
	    }
	    ELSE
	    {
	        IF (trans_fluid_phase == 2)
	        {
		  { 1573,	[unit_1573],	[unit_1573_help]	}, /* 233	Nm  */
		  { 1574,	[unit_1574],	[unit_1574_help]	}, /* 234	Nl   */
	        }
	        ELSE
	        {
	          IF (trans_fluid_phase == 3)
	          {
		    { 1575,	[unit_1575],	[unit_1575_help]	}, /* 166	Sm  */
		    { 1576,	[unit_1576],	[unit_1576_help]	}, /* 167	Sl   */
		    { 1053,	[unit_1053],	[unit_1053_help]	}, /* 168	sft */
		    { 1531,	[unit_1531y],	[unit_1531y_help]	}, /* 197	sgal */
	          }
	        }
	    }
	    }  // if flow_refernce

//		{ 1035, [unit_1035],	[unit_1035_help]	}, /* 		dm  */
//		{ 1037, [unit_1037],	[unit_1037_help]	}, /* 		mm  */
//		{ 1039, [unit_1039],	[unit_1039_help]	}, /* 		cl   */

	}
	HANDLING 	READ & WRITE;
}


VARIABLE trans_totalizer_reset
{
	LABEL		[trans_totalizer_reset_label];
	HELP		[trans_totalizer_reset_help_label];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,  [cancel]	},
		{	1,  [execute]	}
	}
	HANDLING	READ & WRITE;
}


VARIABLE trans_reset_error_bit
{
	LABEL		[trans_errorbit_reset_label];
	HELP		[trans_errorbit_reset_help_label];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1) 
	{
		DEFAULT_VALUE	0;
		{	0,   [cancel]   },
		{	128, [execute]  }
	}
	HANDLING	READ & WRITE;
}


VARIABLE trans_dist_version
{
	LABEL		[trans_indicator_type_label];
	HELP		[trans_indicator_type_help_label];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
	        DEFAULT_VALUE   0;
	        { 0, "Standard Version" "|de|Standard-Version"},
	        { 1, "Distance Version" "|de|Abstands-Version"}
	}
	HANDLING    READ;
}


UNIT trans_scale_span_unitrelation
{
	trans_scale_span_unit:
	trans_scale_span_value
}


VARIABLE trans_scale_span_unit
{
	LABEL 		[trans_scale_span_value_label];
	HELP  		[trans_scale_span_value_help_label];
	CLASS 		CONTAINED;
	TYPE  		ENUMERATED(2)
	{
		DEFAULT_VALUE 1995;
		{ 1347,	[unit_1347],	[unit_1347_help]	},		/* 28	m/s       */
		{ 1348,	[unit_1348],	[unit_1348_help]	},		/* 131	m/min     */
		{ 1349,	[unit_1349],	[unit_1349_help]	},		/* 19	m/h       */
		{ 1350,	[unit_1350],	[unit_1350_help]	},		/* 29	m/d       */
		{ 1351,	[unit_1351],	[unit_1351_help]	},		/* 24	l/s        */
		{ 1352,	[unit_1352],	[unit_1352_help]	},		/* 17	l/min      */
		{ 1353,	[unit_1353],	[unit_1353_help]	},		/* 138	l/h        */
		{ 1354,	[unit_1354],	[unit_1354_help]	},		/* 214	l/d        */
		{ 1356,	[unit_1356],	[unit_1356_help]	},		/* 26	ft/s      */
		{ 1357,	[unit_1357],	[unit_1357_help]	},		/* 15	ft/min    */
		{ 1358,	[unit_1358],	[unit_1358_help]	},		/* 130	ft/h      */
		{ 1359,	[unit_1359],	[unit_1359_help]	},		/* 27	ft/d      */
		{ 1362,	[unit_1362],	[unit_1362_help]	},		/* 22	usgal/s    */
		{ 1363,	[unit_1363],	[unit_1363_help]	},		/* 16	usgal/min  */
		{ 1364,	[unit_1364],	[unit_1364_help]	},		/* 136	usgal/h    */
		{ 1365,	[unit_1365],	[unit_1365_help]	},		/* 235	usgal/d    */
		{ 1367,	[unit_1367],	[unit_1367_help]	},		/* 137	Impgal/s   */
		{ 1368,	[unit_1368],	[unit_1368_help]	},		/* 18	Impgal/min */
		{ 1369,	[unit_1369],	[unit_1369_help]	},		/* 30	Impgal/h   */
		{ 1370,	[unit_1370],	[unit_1370_help]	},		/* 31	Impgal/d   */


		{ 1588,	[unit_1588],	[unit_1588_help]	},		/* 246	Nm/s      */
		{ 1589,	[unit_1589],	[unit_1589_help]	},		/* 241	Nm/min    */
		{ 1590,	[unit_1590],	[unit_1590_help]	},		/* 121	Nm/h      */
		{ 1591,	[unit_1591y],	[unit_1591y_help]	},		/* 247	Nm/d      */
		{ 1592,	[unit_1592],	[unit_1592_help]	},		/* 248	Nl/s       */
		{ 1593,	[unit_1593],	[unit_1593_help]	},		/* 242	Nl/min     */
		{ 1594,	[unit_1594],	[unit_1594_help]	},		/* 122	Nl/h       */
		{ 1595,	[unit_1595y],	[unit_1595_help]	},		/* 249	Nl/d       */

		{ 1604,	[unit_1604y],	[unit_1604y_help]	},		/* 208	scf/s      */
		{ 1360,	[unit_1360],	[unit_1360y_help]	},		/* 123	scf/min    */
		{ 1361,	[unit_1361],	[unit_1361y_help]	},		/* 240	scf/h      */
		{ 1605,	[unit_1605y],	[unit_1605y_help]	}		/* 209	scf/d      */


		{ 1326,	[unit_1326],	[unit_1326_help]	}, /* 217	t/s        */
		{ 1327,	[unit_1327],	[unit_1327_help]	}, /* 77	t/min      */
		{ 1328,	[unit_1328],	[unit_1328_help]	}, /* 78	t/h        */
		{ 1329,	[unit_1329],	[unit_1329_help]	}, /* 79	t/d        */
		{ 1322,	[unit_1322],	[unit_1322_help]	}, /* 73	kg/s       */
		{ 1323,	[unit_1323],	[unit_1323_help]	}, /* 74	kg/min     */
		{ 1324,	[unit_1324],	[unit_1324_help]	}, /* 75	kg/h       */
		{ 1325,	[unit_1325],	[unit_1325_help]	}, /* 76	kg/d       */
		{ 1330,	[unit_1330],	[unit_1330_help]	}, /* 80	lb/s       */
		{ 1331,	[unit_1331],	[unit_1331_help]	}, /* 81	lb/min     */
		{ 1332,	[unit_1332],	[unit_1332_help]	}, /* 82	lb/h       */
		{ 1333,	[unit_1333],	[unit_1333_help]	}, /* 83	lb/d       */
		{ 1338,	[unit_1338],	[unit_1338_help]	}, /* 220	Lton/s     */
		{ 1339,	[unit_1339],	[unit_1339_help]	}, /* 243	Lton/min   */
		{ 1340,	[unit_1340],	[unit_1340_help]	}, /* 87	Lton/h     */
		{ 1341,	[unit_1341],	[unit_1341_help]	}  /* 88	Lton/d     */
                { 1995, func1_AI_out_unit_text, "Textual unit" }
	}
	HANDLING 	READ;
    VALIDITY IF (trans_eepr_revision == 1285) { FALSE; } ELSE { TRUE; }
//        CONSTANT_UNIT   FIND_DEFAULT_UNIT(trans_default_channel);
}



VARIABLE trans_scale_span_value
{
	LABEL 		[trans_scale_span_value_label];
	HELP  		[trans_scale_span_value_help_label];
	CLASS 		CONTAINED;
	TYPE  		FLOAT
	{
	    DEFAULT_VALUE 100.0;
	}
	HANDLING 	READ;
//        CONSTANT_UNIT   FIND_DEFAULT_UNIT(trans_default_channel);
}


VARIABLE trans_soft_revision
{
	LABEL		[trans_soft_revision_label];
	HELP		[trans_soft_revision_help_label];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE " ";
	}
	HANDLING	READ;
}

VARIABLE trans_hard_revision
{
	LABEL		[trans_hard_revision_label];
	HELP		[trans_hard_revision_help_label];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE " ";
	}
	HANDLING	READ;
}



UNIT trans_percent_unitrelation
{
	trans_percent_units:
	trans_percent,
	percent_hundred_dummy,
	percent_null_dummy
}


VARIABLE trans_percent
{
	LABEL		[trans_percent_scale_label];
	HELP		[trans_percent_scale_help_label];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100.0;   /* % */
		DISPLAY_FORMAT	".2f";
	}
	HANDLING	READ;
}

VARIABLE trans_percent_status_quality
{
	/* BITMASK 0xfc */

	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0; 
		STATUS_OUTPUT_NO_RCAS
	}
	HANDLING	READ;
}

trans_percent_fstatus_limit				LIKE VARIABLE	trans_percent_status_quality
{
	/* BITMASK 0x03 */
	REDEFINE LABEL	[status_limit];		
	REDEFINE TYPE	ENUMERATED (1)
	{
		STATUS_OUTPUT_LIMIT
	}
}

VARIABLE trans_percent_units
{
	LABEL 		[trans_percent_scale_unit_label];
	HELP  		[trans_percent_scale_unit_help_label];
	CLASS 		CONTAINED;
	TYPE  		ENUMERATED(2)
	{
	   	DEFAULT_VALUE 1342;   /* % */
		{ 1342,	[unit_1342],	[unit_1342_help]	},
	}
	HANDLING 	READ;
}



UNIT trans_primary_unitrelation
{
	trans_primary_units:
	trans_primary_value
}

VARIABLE trans_primary_value
{
	LABEL		[trans_raw_scale_value_label];
	HELP		[trans_raw_scale_value_help_label];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 8.0;   /* mm */
		DISPLAY_FORMAT		".3f";
	}
	HANDLING	READ;
}


VARIABLE trans_primary_value_status_quality
{
	/* BITMASK 0xfc */

	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0; 
		STATUS_OUTPUT_NO_RCAS
	}
	HANDLING	READ;
}

trans_primary_status_value_limit				LIKE VARIABLE	trans_primary_value_status_quality
{
	/* BITMASK 0x03 */
	REDEFINE LABEL	[status_limit];		
	REDEFINE TYPE	ENUMERATED (1)
	{
		STATUS_OUTPUT_LIMIT
	}
}

VARIABLE trans_primary_units
{
	LABEL 		[trans_raw_scale_unit_label];
	HELP  		[trans_raw_scale_unit_help_label];
	CLASS 		CONTAINED;
	TYPE  		ENUMERATED(2)
	{
	   	DEFAULT_VALUE 1013;   /* mm */
		{ 1013,	[unit_1013],	[unit_1013_help]	},
	}
	HANDLING 	READ;
}


VARIABLE    trans_hart_dev_stat1
{
	LABEL		[trans_device_status_1_label];
	HELP		[trans_device_status_1_help_label];
	CLASS		CONTAINED & DYNAMIC ;
	TYPE		BIT_ENUMERATED (1)
	{
	   	DEFAULT_VALUE 	0x00;   
	    {	0x00,	[dia_TB_NO_ERROR],	[dia_TB_NO_ERROR]  },
	    {	0x01,	[dia_TB_RAM_ERROR],	[dia_TB_RAM_ERROR] },
	    {	0x02,	[dia_TB_ADC_ERROR],	[dia_TB_ADC_ERROR] },
	    {	0x04,	[dia_TB_ADJ_ERROR],	[dia_TB_ADJ_ERROR] },
	    {	0x08,	[dia_TB_CAL_ERROR],	[dia_TB_CAL_ERROR] },
	    {	0x10,	[dia_TB_TOT_ERROR],	[dia_TB_TOT_ERROR] },
	    {	0x20,	[dia_TB_OVR_ERROR],	[dia_TB_OVR_ERROR] },
	    {	0x40,	[dia_TB_INT_ERROR],	[dia_TB_INT_ERROR] },
	    {	0x80,	[dia_TB_RESERVED8],	[dia_TB_RESERVED8] }
	}
	HANDLING READ ;
}


VARIABLE    trans_hart_dev_stat2
{
	LABEL		[trans_device_status_2_label];
	HELP		[trans_device_status_2_help_label];
	CLASS		CONTAINED & DYNAMIC ;
	TYPE 		BIT_ENUMERATED (1)
	{
	   	DEFAULT_VALUE	0x00;   
	    {	0x00,	[dia_TB_NO_ERROR],	[dia_TB_NO_ERROR]   },
	    {	0x01,	[dia_TB_TMP_ERROR],	[dia_TB_TMP_ERROR]  },
	    {	0x02,	[dia_TB_RESERVED10],	[dia_TB_RESERVED10] },
	    {	0x04,	[dia_TB_RESERVED11],	[dia_TB_RESERVED11] },
	    {	0x08,	[dia_TB_RESERVED12],	[dia_TB_RESERVED12] },
	    {	0x10,	[dia_TB_PWR_ERROR],	[dia_TB_PWR_ERROR]  },
	    {	0x20,	[dia_TB_RESERVED14],	[dia_TB_RESERVED14] },
	    {	0x40,	[dia_TB_RESERVED15],	[dia_TB_RESERVED15] },
	    {	0x80,	[dia_TB_HWR_ERROR],	[dia_TB_HWR_ERROR]  }
	}
	HANDLING READ ;
}


VARIABLE trans_default_channel
{
	LABEL		[trans_default_channel_label];
	HELP		[trans_default_channel_help_label];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
	    DEFAULT_VALUE   CHANNEL1;
	    { CHANNEL1, "Volume Flow" "|de|Volumenflu"},
	    { CHANNEL2, "Mass Flow" "|de|Massenflu"}
	}
	HANDLING    READ;
}


VARIABLE trans_eepr_revision
{
	LABEL		[trans_eeprom_revision_label];
	HELP		[trans_eeprom_revision_help_label];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}



VARIABLE percent_hundred_dummy
{
	LABEL		[label_blanks_label];
	HELP		[label_blanks_label];
	CLASS		LOCAL;
	TYPE		FLOAT
	{
	    DEFAULT_VALUE   100.0;
	}
}


VARIABLE percent_null_dummy
{
	LABEL		[label_blanks_label];
	HELP		[label_blanks_label];
	CLASS		LOCAL;
	TYPE		FLOAT
	{
	    DEFAULT_VALUE   0.0;
	}
}



VARIABLE trans_wtm_soft_revision
{
	LABEL		[trans_wtm_soft_revision_label];
	HELP		[trans_wtm_soft_revision_help_label];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE 0;
	}
	HANDLING	READ;
}

VARIABLE trans_fbk_soft_revision
{
	LABEL		[trans_fbk_soft_revision_label];
	HELP		[trans_fbk_soft_revision_help_label];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE 0;
	}
	HANDLING	READ;
}

VARIABLE trans_tb_status_handling
{
	LABEL		[trans_tb_status_handling_label];
	HELP		[trans_tb_status_handling_help_label];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0;
		{	0,   "Normal Status Handling" "|de|Normal Status Handling"},
		{	1,   "Disable Low Status"     "|de|Schalte Low Status ab" },
		{	2,   "Disable High Status"    "|de|Schalte High Status ab" },
		{	3,   "Disable Low/High Status""|de|Schalte Low/High Status ab" },
	}
	HANDLING	READ & WRITE;
}






//---------------------------------------------------------------------
//    Transducer Block 1:  Standard params.
//---------------------------------------------------------------------

COMMAND read_trans_blk
{
	BLOCK transducer_block;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_blk_reserve, trans_blk_object, trans_blk_parent_class, trans_blk_class,
			trans_blk_dd_reference, trans_blk_dd_rev, trans_blk_profile, trans_blk_profile_rev,
			trans_blk_execution_time, trans_blk_num_parameters, trans_blk_index_view_1,
			trans_blk_num_view_lists
		}
	}
}

COMMAND read_trans_st_rev
{
	BLOCK transducer_block;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_st_rev
		}
	}
}

COMMAND read_trans_tag_desc
{
	BLOCK transducer_block;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_tag_desc
		}
	}
}

COMMAND write_trans_tag_desc
{
	BLOCK transducer_block;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_tag_desc
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans_strategy
{
	BLOCK transducer_block;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_strategy
		}
	}
}

COMMAND write_trans_strategy
{
	BLOCK transducer_block;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_strategy
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans_alert_key
{
	BLOCK transducer_block;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
            trans_alert_key
		}
	}
}

COMMAND write_trans_alert_key
{
	BLOCK transducer_block;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
            trans_alert_key
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans_target_mode
{
	BLOCK transducer_block;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_target_mode
		}
	}
}

COMMAND write_trans_target_mode
{
	BLOCK transducer_block;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_target_mode
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans_mode
{
	BLOCK transducer_block;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			 trans_actual_mode, trans_permitted_mode, trans_normal_mode
		}
	}
}

COMMAND read_trans_alarm
{
	BLOCK transducer_block;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_current_state_alarm_sum, trans_unacknowledged_state_alarm_sum,
			trans_unreported_state_alarm_sum, trans_disabled_state_alarm_sum
		}
	}
}

//---------------------------------------------------------------------
//    Transducer Block 1: Additional parameters for YPA pH
//---------------------------------------------------------------------


COMMAND read_trans_calibration_factor
{
	BLOCK transducer_block;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_calibration_factor
		}
	}
}

COMMAND write_trans_calibration_factor
{
	BLOCK transducer_block;
	INDEX 8;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_calibration_factor
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans_low_flow_cutoff
{
	BLOCK transducer_block;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_low_flow_cutoff
		}
	}
}

COMMAND write_trans_low_flow_cutoff
{
	BLOCK transducer_block;
	INDEX 9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_low_flow_cutoff
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans_measurement_mode
{
	BLOCK transducer_block;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_measurement_mode
		}
	}
}

COMMAND write_trans_measurement_mode
{
	BLOCK transducer_block;
	INDEX 10;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_measurement_mode
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans_flow_direction
{
	BLOCK transducer_block;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_flow_direction
		}
	}
}

COMMAND write_trans_flow_direction
{
	BLOCK transducer_block;
	INDEX 11;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_flow_direction
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans_zero_point
{
	BLOCK transducer_block;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_zero_point
		}
	}
}

COMMAND write_trans_zero_point
{
	BLOCK transducer_block;
	INDEX 12;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_zero_point
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans_zero_point_adjust
{
	BLOCK transducer_block;
	INDEX 13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_zero_point_adjust
		}
	}
}

COMMAND write_trans_zero_point_adjust
{
	BLOCK transducer_block;
	INDEX 13;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_zero_point_adjust
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans_zero_point_units
{
	BLOCK transducer_block;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_zero_point_units
		}
	}
}

COMMAND write_trans_zero_point_units
{
	BLOCK transducer_block;
	INDEX 14;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_zero_point_units
		}
		REPLY
		{
		}
	}
}


COMMAND read_nominal_size
{
	BLOCK transducer_block;
	INDEX 15;
	OPERATION READ ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_nominal_size	
		}
	}
}



COMMAND read_nominal_size_units
{
	BLOCK transducer_block;
	INDEX 16;
	OPERATION READ ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_nominal_size_units	
		}
	}
}


COMMAND write_nominal_size_units
{
	BLOCK transducer_block;
	INDEX 16;
	OPERATION WRITE ;
	TRANSACTION
	{
		REQUEST
		{
			trans_nominal_size_units	
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans_volume_flow
{
	BLOCK transducer_block;
	INDEX 17;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_volume_flow_value, 
			trans_volume_flow_status_quality	<0xFC>,
			trans_volume_flow_status_limit		<0x03>
		}
	}
}

COMMAND read_trans_volume_flow_unit
{
	BLOCK transducer_block;
	INDEX 18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_volume_flow_unit
		}
	}
}

COMMAND write_trans_volume_flow_unit
{
	BLOCK transducer_block;
	INDEX 18;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_volume_flow_unit
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans_volume_flow_lower_limit
{
	BLOCK transducer_block;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_volume_flow_lower_limit
		}
	}
}


// kein write

COMMAND read_trans_volume_flow_upper_limit
{
	BLOCK transducer_block;
	INDEX 20;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_volume_flow_upper_limit
		}
	}
}


// kein write


COMMAND read_trans_mass_flow
{
	BLOCK transducer_block;
	INDEX 21;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_mass_flow_value, 
			trans_mass_flow_status_quality 	<0xFC>,
			trans_mass_flow_status_limit	<0x03>
		}
	}
}

COMMAND read_trans_mass_flow_unit
{
	BLOCK transducer_block;
	INDEX 22;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_mass_flow_unit
		}
	}
}

COMMAND write_trans_mass_flow_unit
{
	BLOCK transducer_block;
	INDEX 22;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_mass_flow_unit
		}
		REPLY
		{
		}
	}
}



COMMAND read_trans_mass_flow_lower_limit
{
	BLOCK transducer_block;
	INDEX 	23	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_mass_flow_lower_limit
		}
	}
}

// kein write


COMMAND read_trans_mass_flow_upper_limit
{
	BLOCK transducer_block;
	INDEX 	24	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_mass_flow_upper_limit
		}
	}
}


// kein write


COMMAND read_trans_density
{
	BLOCK transducer_block;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans_density,
			trans_density_status_quality	<0xFC>,
			trans_density_status_limit	<0x03>
		}
	}

}

COMMAND  read_trans_density_units
{
	BLOCK transducer_block;
	INDEX 	26 ;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_density_unit
		}
	}
}

// Special version
COMMAND  write_trans_density_units
{
	BLOCK transducer_block;
	INDEX 	26 ;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_density_unit
		}
		REPLY
		{	
		}
	}
}
// Special version



COMMAND  read_trans_temperatures
{
	BLOCK transducer_block;
	INDEX 	29 ;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_temperature,
			trans_temperature_status_quality <0xFC>,
			trans_temperature_status_limit	 <0x03>
		}
	}
}

COMMAND  read_trans_temperature_units
{
	BLOCK transducer_block;
	INDEX 	30 ;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_temperature_unit
		}
	}
}


COMMAND  write_trans_temperature_unit
{
	BLOCK transducer_block;
	INDEX 	30	;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_temperature_unit
		}
		REPLY
		{	
		}
	}
}





// Manufacturer specific parameter ////////////////////////////////////////////


COMMAND  read_trans_oper_viscosity	     	//53;2;69
{
	BLOCK transducer_block;
	INDEX 	53	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_oper_viscosity
		}
	}
}

COMMAND  read_trans_oper_viscosity_unit		//54;2;70
{
	BLOCK transducer_block;
	INDEX 	54	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_oper_viscosity_unit
		}
	}
}


COMMAND  read_trans_oper_pressure 	   	//55;2;71
{
	BLOCK transducer_block;
	INDEX 	55	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_oper_pressure
		}
	}
}

COMMAND  read_trans_oper_pressure_unit		//56;2;72
{
	BLOCK transducer_block;
	INDEX 	56	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_oper_pressure_unit
		}
	}
}


COMMAND  read_trans_pressure_ref		//57;2;73
{
	BLOCK transducer_block;
	INDEX 	57	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_pressure_ref
		}
	}
}

COMMAND  read_trans_press_ref_unit		//58;2;74
{
	BLOCK transducer_block;
	INDEX 	58	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_press_ref_unit
		}
	}
}


COMMAND  read_trans_oper_temperature		//59;2;75
{
	BLOCK transducer_block;
	INDEX 	59	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_oper_temperature
		}
	}
}

COMMAND  read_trans_oper_temp_unit		//60;2;76
{
	BLOCK transducer_block;
	INDEX 	60	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_oper_temp_unit
		}
	}
}


COMMAND  read_trans_oper_condition		//61;2;77
{
	BLOCK transducer_block;
	INDEX 	61	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_oper_condition
		}
	}
}


COMMAND  read_trans_fluid_phase			//62;2;78
{
	BLOCK transducer_block;
	INDEX 	62	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_fluid_phase
		}
	}
}

COMMAND  read_trans_flow_reference		//63;2;79
{
	BLOCK transducer_block;
	INDEX 	63	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_flow_reference
		}
	}
}

COMMAND  read_trans_commission_no
{
	BLOCK transducer_block;
	INDEX 	64	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_commission_no
		}
	}
}

COMMAND  read_trans_model_code
{
	BLOCK transducer_block;
	INDEX 	65	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_model_code
		}
	}
}

COMMAND  read_trans_fluid_name
{
	BLOCK transducer_block;
	INDEX 	66	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_fluid_name
		}
	}
}


COMMAND  read_trans_totalizer		//67;2;83
{
	BLOCK transducer_block;
	INDEX 	67	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_totalizer,
			trans_totalizer_status_quality 	<0xFC>,
			trans_totalizer_status_limit	<0x03>
		}
	}
}

COMMAND  read_trans_totalizer_units		//68;2;84
{
	BLOCK transducer_block;
	INDEX 	68	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_totalizer_units
		}
	}
}

COMMAND  write_trans_totalizer_units		//68;2;84
{
	BLOCK transducer_block;
	INDEX 	68	;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_totalizer_units
		}
		REPLY
		{	
		}
	}
}


COMMAND  read_trans_totalizer_reset		//69;2;85
{
	BLOCK transducer_block;
	INDEX 	69	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_totalizer_reset
		}
	}
}

COMMAND  write_trans_totalizer_reset		//69;2;85
{
	BLOCK transducer_block;
	INDEX 	69	;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_totalizer_reset
		}
		REPLY
		{	
		}
	}
}



COMMAND  read_trans_reset_error_bit		//70;2;86
{
	BLOCK transducer_block;
	INDEX 	70	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_reset_error_bit
		}
	}
}

COMMAND  write_trans_reset_error_bit		//70;2;86
{
	BLOCK transducer_block;
	INDEX 	70	;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_reset_error_bit
		}
		REPLY
		{	
		}
	}
}



COMMAND  read_trans_dist_version	//71;2;87
{
	BLOCK transducer_block;
	INDEX 	71	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_dist_version
		}
	}
}

COMMAND  read_trans_scale_span_value   	//72;2;88
{
	BLOCK transducer_block;
	INDEX 	72	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_scale_span_value
		}
	}
}

COMMAND  read_trans_soft_revision  		//73;2;89
{
	BLOCK transducer_block;
	INDEX 	73	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_soft_revision
		}
	}
}

COMMAND  read_trans_hard_revision  		//74;2;90
{
	BLOCK transducer_block;
	INDEX 	74	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_hard_revision
		}
	}
}







COMMAND  read_trans_percent			//75;2;91
{
	BLOCK transducer_block;
	INDEX 	75	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_percent,
			trans_percent_status_quality 	<0xFC>,
			trans_percent_status_limit	<0x03>
		}
	}
}


COMMAND  read_trans_percent_units 		//76;2;92
{
	BLOCK transducer_block;
	INDEX 	76	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_percent_units
		}
	}
}

COMMAND  read_trans_primary_value 		//77;2;93
{
	BLOCK transducer_block;
	INDEX 	77	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_primary_value,
			trans_primary_value_status_quality 	<0xFC>,
			trans_primary_value_status_limit	<0x03>
		}
	}
}


COMMAND  read_trans_primary_units		//78;2;94
{
	BLOCK transducer_block;
	INDEX 	78	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_primary_units
		}
	}
}

COMMAND  read_trans_hart_dev_stat1  		//79;2;95
{
	BLOCK transducer_block;
	INDEX 	79	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_hart_dev_stat1
		}
	}
}

COMMAND  read_trans_hart_dev_stat2 		//80;2;96
{
	BLOCK transducer_block;
	INDEX 	80	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_hart_dev_stat2
		}
	}
}



COMMAND  read_trans_default_channel		//81;2;97
{
	BLOCK transducer_block;
	INDEX 	81	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_default_channel
		}
	}
}

COMMAND  read_trans_eepr_revision		//82;2;98
{
	BLOCK transducer_block;
	INDEX 	82	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_eepr_revision
		}
	}
}

COMMAND  read_trans_tb_status_handling		//83;2;99
{
	BLOCK transducer_block;
	INDEX 	83	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_tb_status_handling
		}
	}
}

COMMAND  write_trans_tb_status_handling		//83;2;99
{
	BLOCK transducer_block;
	INDEX 	83	;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans_tb_status_handling
		}
		REPLY
		{	
		}
	}
}



COMMAND  read_trans_scale_span_unit   		//84;2;100
{
	BLOCK transducer_block;
	INDEX 	84	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_scale_span_unit
		}
	}
}

COMMAND  read_trans_wtm_soft_revision		//85;2;101
{
	BLOCK transducer_block;
	INDEX 	85	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_wtm_soft_revision
		}
	}
}

COMMAND  read_trans_fbk_soft_revision		//86;2;102
{
	BLOCK transducer_block;
	INDEX 	86	;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{	
			trans_fbk_soft_revision
		}
	}
}









//*********************************************************************
//    Function Block 1: MENUs  Maintenance
//*********************************************************************


MENU Page_display_trans
{
	LABEL		[menu_dialog_display];  //_measure
	ITEMS
	{
		trans_volume_flow_value,
		trans_mass_flow_value,
		trans_actual_mode,
		BarVal_trans_perc_display,
		BarVal_trans_volume_flow_display,
		trans_volume_flow_status_quality,
		trans_volume_flow_status_limit	<0x03>,
		BarVal_trans_mass_flow_display,
		trans_mass_flow_status_quality,
		trans_mass_flow_status_limit	<0x03>
	}
}

MENU BarVal_trans_perc_display
{
	LABEL		[trans_percent_scale_label];
	ITEMS {
	    trans_percent			(READ_ONLY),
	    percent_null_dummy			(READ_ONLY),
	    percent_hundred_dummy		(READ_ONLY)
	}
}

MENU BarVal_trans_volume_flow_display
{
	LABEL		[trans_volume_flow_value_label];
	ITEMS {
	    trans_volume_flow_value		(READ_ONLY),
	    trans_volume_flow_lower_limit	(READ_ONLY),
	    trans_volume_flow_upper_limit	(READ_ONLY)
	}
}

MENU BarVal_trans_mass_flow_display
{
	LABEL		[trans_mass_flow_value_label];
	ITEMS {
	    trans_mass_flow_value		(READ_ONLY),
	    trans_mass_flow_lower_limit		(READ_ONLY),
	    trans_mass_flow_upper_limit		(READ_ONLY)
	}
}



MENU Tab_m_tb
{
	LABEL		[trans_block_name_label];
	ITEMS
	{
		Tab_m_tb_trans
	}
}



MENU Tab_m_tb_trans
{
	LABEL		[trans_flow];
	ITEMS
	{
		trans_target_mode  		(READ_ONLY),	
		trans_st_rev			(READ_ONLY),
		trans_low_flow_cutoff  		(READ_ONLY),			
		trans_volume_flow_unit  	(READ_ONLY),			
		trans_mass_flow_unit  		(READ_ONLY),			
		trans_measurement_mode  	(READ_ONLY),		
		trans_flow_direction  		(READ_ONLY),			
		Tab_m_tb_measrange_trans,
		Tab_m_tb_control_param_trans,
		Tab_m_tb_temp_density_trans,
		Tab_m_tb_operation,
		Tab_m_tb_medium,
		Tab_m_tb_indicator,
		Tab_m_tb_diagnostic
	}
}

MENU Tab_m_tb_control_param_trans
{
	LABEL		[menu_control_parameter] ;
	ITEMS
	{
		trans_calibration_factor	(READ_ONLY),		
		trans_zero_point_units		(READ_ONLY),
		trans_zero_point		(READ_ONLY),		
		trans_nominal_size		(READ_ONLY),			
		trans_nominal_size_units	(READ_ONLY)
	}
}


MENU Tab_m_tb_measrange_trans
{
	LABEL		[menu_input_measrange] ;
	ITEMS
	{
		trans_volume_flow_upper_limit	(READ_ONLY),		
		trans_volume_flow_lower_limit	(READ_ONLY),		
		trans_mass_flow_upper_limit	(READ_ONLY),		
		trans_mass_flow_lower_limit	(READ_ONLY)		
	}
}


MENU Tab_m_tb_temp_density_trans
{
	LABEL		[trans_temperature] ;
	ITEMS
	{
		trans_temperature    		(READ_ONLY),
		trans_temperature_unit		(READ_ONLY)
	}
}


MENU Tab_m_tb_operation
{
	LABEL		[trans_operation_condition_label];
	ITEMS
	{
		trans_density,
	        trans_oper_viscosity,     	//53;2;69
	        trans_oper_pressure,    	//55;2;71
	        trans_pressure_ref,		//57;2;73
	        trans_oper_temperature,		//59;2;75
	        trans_oper_condition		//61;2;77
	}
}

MENU Tab_m_tb_medium
{
	LABEL		[trans_medium_name_label];
	ITEMS
	{
	        trans_fluid_phase,		//62;2;78
	        trans_flow_reference,		//63;2;79
	        trans_fluid_name
	}
}

MENU Tab_m_tb_indicator
{
	LABEL		[trans_indicator_name_label];
	ITEMS
	{
	        trans_totalizer,		//67;2;83
	        trans_totalizer_units,		//67;2;83
	        trans_totalizer_reset,		//69;2;85
	        trans_reset_error_bit		//70;2;86
	        trans_dist_version,		//71;2;87
	        trans_scale_span_value,  	//72;2;88
	        trans_hard_revision,  		//74;2;90
	}
}



MENU Tab_m_tb_diagnostic
{
	LABEL		[trans_diagnostics_settings_label];
	ITEMS
	{
	        trans_hart_dev_stat1,		//79;2;95
	        trans_hart_dev_stat2,		//80;2;96
                trans_tb_status_handling	//83;2;99
	}
}



//*********************************************************************
//    Function Block 1: MENUs  Specialist
//*********************************************************************

MENU Tab_s_tb
{
	LABEL		[trans_block_name_label];
	ITEMS
	{
		Tab_s_tb_trans
	}
}


MENU Tab_s_tb_trans
{
	LABEL		[trans_flow];
	ITEMS
	{
		trans_target_mode,
		trans_st_rev,
		trans_low_flow_cutoff		(READ_ONLY),			
		trans_volume_flow_unit,			
		trans_mass_flow_unit,			
		trans_measurement_mode		(READ_ONLY),		
		trans_flow_direction		(READ_ONLY),			
		Tab_s_tb_measrange_trans,
		Tab_s_tb_control_param_trans,
		Tab_s_tb_temp_density_trans,
		Tab_s_tb_operation,
		Tab_s_tb_medium,
		Tab_s_tb_indicator,
		Tab_s_tb_diagnostic
	}
}



MENU Tab_s_tb_control_param_trans
{
	LABEL		[menu_control_parameter] ;
	ITEMS
	{
		trans_calibration_factor	(READ_ONLY),		
		trans_zero_point_units		(READ_ONLY),
		trans_zero_point		(READ_ONLY),		
		trans_nominal_size		(READ_ONLY),			
		trans_nominal_size_units
	}
}


MENU Tab_s_tb_measrange_trans
{
	LABEL		[menu_input_measrange] ;
	ITEMS
	{
		trans_volume_flow_upper_limit	(READ_ONLY),		
		trans_volume_flow_lower_limit	(READ_ONLY),		
		trans_mass_flow_upper_limit	(READ_ONLY),		
		trans_mass_flow_lower_limit	(READ_ONLY)		
	}
}


MENU Tab_s_tb_temp_density_trans
{
	LABEL		[trans_temperature] ;
	ITEMS
	{
		trans_temperature		(READ_ONLY),
		trans_temperature_unit
	}
}


MENU Tab_s_tb_operation
{
	LABEL		[trans_operation_condition_label];
	ITEMS
	{
		trans_density,
                trans_density_unit,
	        trans_oper_viscosity,     	//53;2;69
	        trans_oper_pressure,    	//55;2;71
	        trans_pressure_ref,		//57;2;73
	        trans_oper_temperature,		//59;2;75
	        trans_oper_condition		//61;2;77
	}
}

MENU Tab_s_tb_medium
{
	LABEL		[trans_medium_name_label];
	ITEMS
	{
	        trans_fluid_phase,		//62;2;78
	        trans_flow_reference,		//63;2;79
	        trans_fluid_name
	}
}

MENU Tab_s_tb_indicator
{
	LABEL		[trans_indicator_name_label];
	ITEMS
	{
	        trans_totalizer,		//67;2;83
	        trans_totalizer_units,		//67;2;83
	        trans_totalizer_reset,		//69;2;85
	        trans_reset_error_bit,		//70;2;86
	        trans_dist_version,		//71;2;87
	        trans_scale_span_value,  	//72;2;88
	        trans_hard_revision,  		//74;2;90
	}
}


MENU Tab_s_tb_diagnostic
{
	LABEL		[trans_diagnostics_settings_label];
	ITEMS
	{
	        trans_hart_dev_stat1,		//79;2;95
	        trans_hart_dev_stat2,		//80;2;96
                trans_tb_status_handling	//83;2;99
	}
}

